%bcond_without  templates

%define bits    %{__isa_bits}
%define versuff stable

Name:           godot
Version:        2.0.1
Release:        %mkrel 1
Summary:        Multi-platform 2D and 3D game engine with a feature rich editor
Group:          Development/Tools
License:        MIT
URL:            http://www.godotengine.org
Source0:        https://github.com/godotengine/godot/archive/%{version}-%{versuff}/%{name}-%{version}-%{versuff}.tar.gz

ExclusiveArch:  %ix86 x86_64

BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  scons
Recommends:     %{name}-demos

%if %{with templates}
BuildRequires:  libstdc++-static-devel
BuildRequires:  upx
Recommends:     %{name}-templates-linux%{bits}
%ifarch x86_64
Recommends:     %{name}-templates-linux32
%endif
%endif

%description
Godot is an advanced, feature packed, multi-platform 2D and 3D game engine.
It provides a huge set of common tools, so you can just focus on making
your game without reinventing the wheel.

Godot is completely free and open source under the very permissive MIT
license. No strings attached, no royalties, nothing. Your game is yours,
down to the last line of engine code.

%files
%doc LICENSE.md README.md
%{_bindir}/%{name}
%if %{with templates}
%dir %{_libexecdir}/%{name}
%endif
%dir %{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg

#----------------------------------------------------------------------

%package        demos
Summary:        Demo projects to learn how to use Godot Engine
BuildArch:      noarch

%description    demos
This package contains the official demo projects to help new users to learn
the features of the game engine.

%files          demos
%{_datadir}/%{name}/demos/

#----------------------------------------------------------------------

%package        server
Summary:        Godot headless binary for servers

%description    server
This package contains the headless binary for the Godot game engine,
particularly suited for running dedicated servers.

%files          server
%{_bindir}/%{name}-server

#----------------------------------------------------------------------

%package        runner
Summary:        Shared binary to play games developed with the Godot engine
Group:          Games/Other

%description    runner
This package contains a %{bits} bits binary for the Linux X11 platform,
which can be used to run any game developed with the Godot engine simply
by pointing to the location of the game's data package.

%files          runner
%doc LICENSE.md README.md
%{_bindir}/%{name}-runner

#----------------------------------------------------------------------

%if %{with templates}
%package        templates-linux%{bits}
Summary:        Godot export templates for Linux %{bits} bits platforms
# Can be later removed, was cauldron only
Obsoletes:      template-linux%{bits} < 2.0-1

%description    templates-linux%{bits}
This package contains release and debug export templates for Linux
%{bits} bits platforms to be used with the Godot engine.

To ensure cross-distro portability, these templates link libstdc++
statically. Note however that those binaries would not work on Fedora
due to incompatible OpenSSL versions linked dynamically.
Use the upstream templates (less secure but more portable) if need be.

%files          templates-linux%{bits}
%{_libexecdir}/%{name}/templates/linux_x11_%{bits}_release
%{_libexecdir}/%{name}/templates/linux_x11_%{bits}_debug
%endif

#----------------------------------------------------------------------

%prep
%setup -q -n %{name}-%{version}-%{versuff}
%autopatch -p1

%build
BUILD_REVISION="mageia"; export BUILD_REVISION

%define common_flags CCFLAGS="%{optflags}" CFLAGS="%{optflags}" LINKFLAGS="%{ldflags}" builtin_zlib=no
%define _scons %scons %common_flags

# Build headless version of the editor
%_scons p=server tools=yes target=release_debug unix_global_settings_path=%{_libexecdir}/%{name}

# Build graphical editor (tools)
%_scons p=x11 tools=yes target=release_debug unix_global_settings_path=%{_libexecdir}/%{name}

# Build game runner (without tools)
%_scons p=x11 tools=no target=release
cp bin/%{name}.x11.opt.%{bits} bin/%{name}.x11.opt.runner.%{bits}

%if %{with templates}
# Build Linux export templates for the current arch
# (akien) To make binaries that will run on any distro, stdc++ has to be
# statically linked. They still won't run on Fedora though due to their
# breakage of OpenSSL's soname: https://github.com/godotengine/godot/issues/1391
%_scons p=x11 tools=no target=release use_static_cpp=yes
%_scons p=x11 tools=no target=release_debug use_static_cpp=yes CCFLAGS= CFLAGS=

# Rename templates
mkdir -p templates
mv bin/%{name}.x11.opt.%{bits} templates/linux_x11_%{bits}_release
mv bin/%{name}.x11.opt.debug.%{bits} templates/linux_x11_%{bits}_debug

# Compress templates
for file in bin/%{name}.x11.opt.runner.%{bits} templates/*; do
    upx $file
done
%endif

%install
install -d %{buildroot}%{_bindir}
install -m755 bin/%{name}.x11.opt.tools.%{bits}           %{buildroot}%{_bindir}/%{name}
install -m755 bin/%{name}.x11.opt.runner.%{bits}          %{buildroot}%{_bindir}/%{name}-runner
install -m755 bin/%{name}_server.server.opt.tools.%{bits} %{buildroot}%{_bindir}/%{name}-server

%if %{with templates}
install -d %{buildroot}%{_libexecdir}/%{name}/templates
cp -a templates/* %{buildroot}%{_libexecdir}/%{name}/templates/
%endif

install -d %{buildroot}%{_datadir}/%{name}
cp -a demos %{buildroot}%{_datadir}/%{name}/

install -D -m644 icon.svg \
    %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}.svg

install -d %{buildroot}%{_datadir}/applications
cat << EOF > %{buildroot}%{_datadir}/applications/%{name}.desktop
[Desktop Entry]
Name=Godot Engine
GenericName=Libre game engine
Comment=%{summary}
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
Categories=Development;IDE;
EOF


%changelog
* Tue Mar 08 2016 akien <akien> 2.0.1-1.mga5
+ Revision: 987285
- Version 2.0.1
- Package demos (in their own package)
- Use Mageia-specific optflags and ldflags
- Set BUILD_REVISION for build branding
- backporting godot 2.0-stable to mga5
- Version 2.0-stable

* Sun Feb 21 2016 akien <akien> 2.0-0.dev.1.mga6
+ Revision: 975107
- imported package godot

